@@ -61,8 +61,8 @@ public:
     {
     }
 
-    void readConfig(const KSharedConfigPtr &config, const QString &group);
-    void saveConfig(KSharedConfigPtr config, const QString &group);
+    void readConfig();
+    void saveConfig();
     void slotMkdir();
 
     void slotCurrentChanged(const QUrl &url);
@@ -92,11 +92,24 @@ public:
     QDialogButtonBox *m_buttons = nullptr;
 };
 
-void KDirSelectDialog::Private::readConfig(const KSharedConfig::Ptr &config, const QString &group)
+void KDirSelectDialog::Private::readConfig()
 {
     m_urlCombo->clear();
 
-    KConfigGroup conf(config, group);
+    QString xdgStateHome = qEnvironmentVariable("XDG_STATE_HOME");
+    if (!xdgStateHome.startsWith(u'/')) {
+        xdgStateHome.clear(); // spec says relative paths should be ignored
+    }
+
+    if (xdgStateHome.isEmpty()) {
+        xdgStateHome = QDir::homePath() + "/.local/state";
+    }
+    KConfig config(xdgStateHome + QStringLiteral("/kdirselectstaterc"), KConfig::SimpleConfig);
+    KConfigGroup conf(&config, QStringLiteral("DirSelect Dialog"));
+
+    KConfig oldConfig("kdeglobals", KConfig::SimpleConfig);
+    oldConfig.group(QStringLiteral("DirSelect Dialog")).moveValuesTo({"DirSelectDialog Size", "History Items", "Splitter State"}, conf);
+
     m_urlCombo->setHistoryItems(conf.readPathEntry("History Items", QStringList()));
 
     const QSize size = conf.readEntry("DirSelectDialog Size", QSize());
@@ -109,15 +122,23 @@ void KDirSelectDialog::Private::readConfig(const KSharedConfig::Ptr &config, con
     }
 }
 
-void KDirSelectDialog::Private::saveConfig(KSharedConfig::Ptr config, const QString &group)
+void KDirSelectDialog::Private::saveConfig()
 {
-    KConfigGroup conf(config, group);
+    QString xdgStateHome = qEnvironmentVariable("XDG_STATE_HOME");
+    if (!xdgStateHome.startsWith(u'/')) {
+        xdgStateHome.clear(); // spec says relative paths should be ignored
+    }
+
+    if (xdgStateHome.isEmpty()) {
+        xdgStateHome = QDir::homePath() + "/.local/state";
+    }
+    KConfig config(xdgStateHome + QStringLiteral("/kdirselectstaterc"), KConfig::SimpleConfig);
+
+    KConfigGroup conf(&config, QStringLiteral("DirSelect Dialog"));
     KConfigGroup::WriteConfigFlags flags(KConfigGroup::Persistent | KConfigGroup::Global);
     conf.writePathEntry("History Items", m_urlCombo->historyItems(), flags);
     conf.writeEntry("DirSelectDialog Size", m_parent->size(), flags);
     conf.writeEntry("Splitter State", m_parent->findChild<QSplitter *>()->saveState(), flags);
-
-    config->sync();
 }
 
 void KDirSelectDialog::Private::slotMkdir()
@@ -397,7 +418,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_startDir = d->m_startURL;
     d->m_rootUrl = d->m_treeView->rootUrl();
 
-    d->readConfig(KSharedConfig::openConfig(), QStringLiteral("DirSelect Dialog"));
+    d->readConfig();
 
     d->m_buttons = new QDialogButtonBox(mainWidget);
     d->m_buttons->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
@@ -535,7 +556,7 @@ void KDirSelectDialog::accept()
 
 void KDirSelectDialog::hideEvent(QHideEvent *event)
 {
-    d->saveConfig(KSharedConfig::openConfig(), QStringLiteral("DirSelect Dialog"));
+    d->saveConfig();
 
     QDialog::hideEvent(event);
 }
